API Reference
=============

Understand and debug ``torch.compile``
--------------------------------------

.. warning::

    It is recommended to read the :doc:`walk_through` to have a basic understanding of how ``torch.compile`` works, before using the following functions.

.. autofunction:: depyf.prepare_debug

.. autofunction:: depyf.debug

Decompile general Python Bytecode/Function
-------------------------------------------

.. autofunction:: depyf.decompile

Enhance PyTorch Logging
-----------------------

.. autofunction:: depyf.install

.. autofunction:: depyf.uninstall
